# -*- coding: utf-8 -*-

# This file is part of the Gedit LaTeX Plugin
#
# Copyright (C) 2007 Michael Zeising
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public Licence as published by the Free Software
# Foundation; either version 2 of the Licence, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public Licence for more 
# details.
#
# You should have received a copy of the GNU General Public Licence along with
# this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
# Street, Fifth Floor, Boston, MA  02110-1301, USA

from gtk import Image
from tempfile import NamedTemporaryFile
from os import system, unlink
from os.path import splitext, dirname

from Installation import Installation
from Logger import debug

class PreviewArea(Image):
	"""
	An area using latex, dvips and Johan Vromans's eps2png to provide a preview for LaTeX source
	"""
	def __init__(self):
		Image.__init__(self)
		
		self.source, self.packages, self.changed, self.escape_refs = None, [], False, False
		
	def set_source(self, source):
		self.source = source
		self.changed = True
	
	def set_packages(self, packages):
		self.packages = packages
		self.changed = True
	
	def set_escape_refs(self, settings):
		self.escape_refs = settings
	
	def render(self):
		if not self.source or not self.changed:
			return
		
		self.changed = False
		
		source = self.source
		
		if self.escape_refs:
			# TODO: besser machen (re replace)
			for n in range(9):
				source = source.replace("#%s" % n, "\\#%s" % n)
		
		source = r'\documentclass{article}%s\pagestyle{empty}\begin{document}%s\end{document}' \
				% ("".join(["\usepackage{%s}" % p for p in self.packages]), source)
		
		debug(self, "render", "<<<%s>>>" % source)
		
		# write to temporary file
		temp_file = NamedTemporaryFile(mode="w", suffix=".tex")
		temp_file.write(source)
		temp_file.flush()
		# truncate suffix
		filename = splitext(temp_file.name)[0]
		# render source
		system('latex -interaction=batchmode -halt-on-error -output-directory "%s" "%s.tex" 1>/dev/null && dvips -D 120 -q -E -o "%s.eps" "%s.dvi" && %s/util/eps2png -pngalpha -resolution=120 "%s.eps"' % (dirname(filename), filename, filename, filename, Installation().path, filename))
		# load image
		self.set_from_file(filename + ".png")
		# cleanup
		temp_file.close()
		for suffix in [".dvi", ".eps", ".png"]:
			try:
				unlink(filename + suffix)
			except OSError:
				pass
				