# -*- coding: utf-8 -*-

# This file is part of the Gedit LaTeX Plugin
#
# Copyright (C) 2007 Michael Zeising
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public Licence as published by the Free Software
# Foundation; either version 2 of the Licence, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public Licence for more 
# details.
#
# You should have received a copy of the GNU General Public Licence along with
# this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
# Street, Fifth Floor, Boston, MA  02110-1301, USA

#from elements import *
from CommandStore import *

class VariantProposal(object):
	"""
	This is a proposal as shown in the ProposalPopup.
	"""
	
	def __init__(self, variant):
		self.__variant = variant
	
	def __str__(self):
		"""
		Return a string representation of this proposal (mainly used for sorting)
		"""
		return self.__variant.command.name
	
	@property
	def label(self):
		"""
		Return the string that is to be shown in the proposal popup
		"""
		s = self.__variant.command.name
		
		for argument in self.__variant.arguments:
			if type(argument) is MandatoryArgument:
				s += "{<i>%s</i>}" % argument.label
			elif type(argument) is OptionalArgument:
				s += "[<i>%s</i>]" % argument.label
			elif type(argument) is VectorArgument:
				s += "(%s)" % ",".join(["<i>%s</i>" % c.label for c in argument.components])
		
		if self.__variant.command.package:
			s += " <b>%s</b>" % self.__variant.command.package
		
		return s
	
	@property
	def pair(self):
		"""
		Return the source parts to be inserted left and right of the cursor
		when this proposal is selected
		"""
		skeleton = self.__variant.skeleton
		if skeleton:
			return (self.__variant.command.name + skeleton[0], skeleton[1:])
		else:
			return (self.__variant.command.name, None)
	
	@property
	def package(self):
		return self.__variant.command.package


class ChoiceProposal(object):
	"""
	"""
	def __init__(self, choice):
		self.__choice = choice
	
	def __str__(self):
		return self.__choice.value
	
	@property
	def label(self):
		s = self.__choice.value
		if self.__choice.package:
			s += " <b>%s</b>" % self.__choice.package
		return s
	
	@property
	def pair(self):
		return (self.__choice.value, None)
	
	@property
	def package(self):
		return self.__choice.package
	
	@property
	def doc(self):
		return self.__choice.doc
	