# -*- coding: utf-8 -*-

# This file is part of the Gedit LaTeX Plugin
#
# Copyright (C) 2007 Michael Zeising
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public Licence as published by the Free Software
# Foundation; either version 2 of the Licence, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public Licence for more 
# details.
#
# You should have received a copy of the GNU General Public Licence along with
# this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
# Street, Fifth Floor, Boston, MA  02110-1301, USA

from LaTeXPlugin.Logger import debug, error

BUS_NAME = 'org.gedit.LaTeXPlugin'
OBJECT_PATH = '/org/gedit/DBusInterface'

try:
	from dbus import SessionBus
	from dbus.service import Object, method, BusName
	import dbus.glib
	
	class DBusInterface(Object):
		"""
		The DBUSInterface is listening for DVI inverse search commands and
		scrolls the document to the appropriate line
		"""
		def __init__(self, instance, bus_name, object_path=OBJECT_PATH):
			Object.__init__(self, bus_name, object_path)
			
			self.__instance = instance

		@method('org.gedit.LaTeXPluginIFace')
		def inverse(self, filename, line):
			debug(self, "Got inverse DVI search: %s %s" % (filename, line))
			
			self.__instance.set_active_tab_by_filename(filename)
			wrapper = self.__instance.get_active_wrapper()
			wrapper.select_line(line - 1)
			
except ImportError:
	error(self, None, "Failed to import D-Bus bindings")
	

class DBusController(object):
	"""
	"""
	def __init__(self, instance):
		self.__instance = instance
		
		try:
			bus_name = BusName(BUS_NAME, bus=SessionBus())
			self.dbus_interface = DBusInterface(self.__instance, bus_name)
		except NameError:
			pass
		except KeyError, s:
			error(self, "__init__", s)
			