# -*- coding: utf-8 -*-

# This file is part of the Gedit LaTeX Plugin
#
# Copyright (C) 2007 Michael Zeising
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public Licence as published by the Free Software
# Foundation; either version 2 of the Licence, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public Licence for more 
# details.
#
# You should have received a copy of the GNU General Public Licence along with
# this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
# Street, Fifth Floor, Boston, MA  02110-1301, USA

from xml.sax import ContentHandler, parse

class Language(object):
	def __init__(self, name):
		self.__name = name
		self.__dialects = []
	
	@property
	def name(self):
		return self.__name
	
	@property
	def dialects(self):
		return self.__dialects

class Dialect(object):
	def __init__(self, name, default):
		self.__name = name
		self.__default = default
	
	@property
	def name(self):
		return self.__name
	
	@property
	def default(self):
		return self.__default

class LanguagesParser(ContentHandler):
	"""
	This parses the languages.xml file containing the available languages for listings
	"""
	def __init__(self):
		self.__languages = None
		self.__language = None
	
	def startElement(self, name, attributes):
		if name == "language":
			l = Language(attributes["name"])
			self.__languages.append(l)
			self.__language = l
		elif name == "dialect":
			default = False
			try:
				if attributes["default"] == "true":
					default = True
			except KeyError:
				pass
			
			self.__language.dialects.append(Dialect(attributes["name"], default))
		elif name == "no-dialect":
			self.__language.dialects.append(Dialect(None, True))
			
	def parse(self, languages, filename):
		"""
		Parse XML
		
		"languages" must be a list
		"""
		self.__languages = languages
		parse(filename, self)
		