# -*- coding: utf-8 -*-

# This file is part of the Gedit LaTeX Plugin
#
# Copyright (C) 2007 Michael Zeising
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public Licence as published by the Free Software
# Foundation; either version 2 of the Licence, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public Licence for more 
# details.
#
# You should have received a copy of the GNU General Public Licence along with
# this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
# Street, Fifth Floor, Boston, MA  02110-1301, USA

from gtk import Image

from SymbolDefinition import SymbolDefinition
from SymbolView import SymbolView
from LaTeXPlugin.Installation import Installation
from LaTeXPlugin.Logger import debug
from LaTeXPlugin.document.DocumentHelper import LANGUAGE_LATEX

class SymbolController(object):
	"""
	Everything regarding symbols is done here to relieve the PluginInstance
	"""
	def __init__(self, window_helper):
		debug(self, "__init__")
		
		self.__window_helper = window_helper
		self.__symbols_loaded = False
		
		self.__view = SymbolView()
		self.__view.connect("symbol-selected", self.__symbol_selected)
		self.__view.connect("group-expanded", self.__group_expander_activated)
		
		self.__handler_id_expose = self.__view.connect("expose-event", self.__view_exposed)
		
		# add page
		image = Image()
		image.set_from_file(Installation().path + "/pixmaps/symbols.png")
		
		self.__window_helper.window.get_side_panel().add_item(self.__view, "Symbols", image)
		
		debug(self, "__init__", "done")
	
	def deactivate(self):
		self.__window_helper.window.get_side_panel().remove_item(self.__view)
	
	def __load_symbols(self):
		"""
		Read symbol definition and put it in the view
		"""
		debug(self, "__load_symbols", "reading symbols.xml")
		self.definition = SymbolDefinition(Installation().symbols_filename)
		
		debug(self, "__load_symbols", "reading symbols.xml done, adding groups")
		
		for group in self.definition.groups:
			self.__view.add_group(group)
		
		self.__symbols_loaded = True
		
		debug(self, "__load_symbols", "adding groups done")
	
	def __view_exposed(self, view, event):
		"""
		The view has been exposed.
		
		Read the symbol definition if this happens for the first time.
		"""
		debug(self, "__view_exposed")
		
		if not self.__symbols_loaded:
			self.__load_symbols()
			self.__view.disconnect(self.__handler_id_expose)	# disconnect signal
	
	def __symbol_selected(self, view, source):
		helper = self.__window_helper.document_helper_manager.active_helper
		if helper.get_language() == LANGUAGE_LATEX:
			helper.language_helper.insert_source(source)
	
	def __group_expander_activated(self, view, label, expanded):
		self.definition.set_group_visible(label, expanded)
	
	
		